<?php
/**
 * Easy Like Rating
 *
 * @package     Easy_Like_Rating
 * @author      DuckWins Team
 * @copyright   2019 DuckWins
 * @license     GPL-3.0
 *
 * @wordpress-plugin
 * Plugin Name: Easy Like Rating
 * Plugin URI:  http://duckwins.com/easy-like-rating
 * Description: Give your content a simple heart-like rating system. Easily.
 * Version:     1.0.0
 * Author:      DuckWins Team
 * Author URI:  http://duckwins.com
 * Text Domain: easy-like-rating
 * License:     GPLv3
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

namespace Easy_Like_Rating;

defined( 'ABSPATH' ) || exit;

/**
 * Gets the plugin path.
 *
 * @since 1.0.0
 *
 * @return string
 */
function get_plugin_path() {
	return plugin_dir_path( __FILE__ );
}

/**
 * Gets the plugin url.
 *
 * @since 1.0.0
 */
function get_plugin_url() {
	return plugin_dir_url( __FILE__ );
}

/**
 * Requires the plugin files.
 *
 * @since 1.0.0
 *
 * @param string $path The plugin files path.
 */
function require_files( $path = '' ) {
	$files = glob( get_plugin_path() . trailingslashit( $path ) . '*.php' );

	foreach ( $files as $file ) {
		require_once $file;
	}
}

/**
 * Requires the plugin admin files.
 *
 * @since 1.0.0
 *
 * @param string $path The plugin admin files path.
 */
function require_admin_files( $path = '' ) {
	if ( is_admin() ) {
		require_files( $path );
	}
}

/**
 * Inits the plugin.
 *
 * @since 1.0.0
 */
function init() {
	$hook_postfix = 'dw_easy_like_rating_plugin_loaded';

	do_action( 'before_' . $hook_postfix );

	load_plugin_textdomain( 'easy-like-rating', false, basename( dirname( __FILE__ ) ) . '/languages' );

	require_files( 'includes' );
	require_files( 'includes/scripts' );

	do_action( 'before_' . $hook_postfix );
}
add_action( 'plugins_loaded', __NAMESPACE__ . '\init' );
