<?php

namespace Easy_Like_Rating;

use function Easy_Like_Rating\Scripts\enqueue_rating_script;

function get_post_likes( $post_id ) {
	return get_post_meta( $post_id, get_rating_meta_name() );
}

function count_post_likes( $post_id ) {
	return count( get_post_likes( $post_id ) );
}

function was_post_liked_by_user( $post_id, $user_id ) {
	$post_likes = get_post_likes( $post_id );

	return $post_likes && in_array( $user_id, $post_likes );
}

function like_post( $post_id, $user_id ) {
	if ( was_post_liked_by_user( $post_id, $user_id ) ) {
		return false;
	}

	return add_post_meta( $post_id, get_rating_meta_name(), $user_id );
}

function unlike_post( $post_id, $user_id ) {
	return delete_post_meta( $post_id, get_rating_meta_name(), $user_id );
}

function add_rating_to_post_content( $content ) {
	enqueue_rating_script();

	$post_id = get_the_ID();
	$user    = wp_get_current_user();

	return $content . html_get_rating(
		$post_id,
		$user->ID,
		was_post_liked_by_user( $post_id, $user->ID ),
		'dw_elr_like_post',
		count_post_likes( $post_id )
	);
}
add_filter( 'the_content', __NAMESPACE__ . '\add_rating_to_post_content' );

function ajax_handle_post_likes() {
	if ( wp_verify_nonce( 'dw-easy-like-rating', $_POST['nonce'] ) ) {
		return false;
	}

	$post_id = absint( $_POST['object_id'] );
	$user_id = absint( $_POST['user_id'] );

	$sanitized_action = sanitize_key( $_POST['object_action'] );
	$action = 'like' === $sanitized_action ? $sanitized_action : 'unlike';

	$function_name = __NAMESPACE__ . '\\' . $action . '_post';

	if ( function_exists( $function_name ) ) {
		call_user_func( $function_name, $post_id, $user_id );
	}

	wp_send_json_success();
}
add_action( 'wp_ajax_dw_elr_like_post', __NAMESPACE__ . '\ajax_handle_post_likes' );
